@@ -36,11 +36,11 @@ def get_permission_text(st_mode: int) -> str:
             perm_sets[int(index / 3)][index % 3] = perm
 
     if st_mode & 0o4000 == 0o4000:  # setuid
-        perm_sets[0][-1] = "s"
+        perm_sets[0][-1] = "s" if perm_sets[0][-1] == "x" else "S"
     if st_mode & 0o2000 == 0o2000:  # setgid
-        perm_sets[1][-1] = "s"
+        perm_sets[1][-1] = "s" if perm_sets[1][-1] == "x" else "S"
     if st_mode & 0o1000 == 0o1000:  # sticky
-        perm_sets[2][-1] = "T"
+        perm_sets[2][-1] = "t" if perm_sets[2][-1] == "x" else "T"
 
     return " ".join(
         "".join(
